# conda_environments

[![build status](https://git.geomar.de/python/conda_environments/badges/master/build.svg)](https://git.geomar.de/python/conda_environments/commits/master)

Collection of conda environments and info on where and how to use them.

## Contribute

**Recommended:** [File an issue here][issues] and describe what you need.

**Or:** [Fork this repository here][forks], add an evrionment, and create a
merge request.  (Adding / editing the respective `_env_templates/*yml` and
running `python create_env_files.py` would be ideal.)

[issues]: https://git.geomar.de/python/conda_environments/issues
[forks]: https://git.geomar.de/python/conda_environments/forks

## See available environments

Have a look at
[envs/](https://git.geomar.de/python/conda_environments/tree/master/envs/).

There, e.g., is an environment `py3_std` described in the file `py2_std.yml`.
As with this example, all other env names also match the file name before the
`.yml`.

## Using the environments

In the standard datacenters, there is
`<willis_home_dir>/TM/software/miniconda3_latest` which holds the environments
defined here.

Activate the desired environment with:
```bash
source <willis_home_dir>/TM/software/miniconda3_latest/bin/activate <envname>
```

De-Activate the environment with:
```bash
source deactivate
```

(Nesh: `smomw122`; HLRN: `shkifmwr`; Geomar: `wrath`)

## A note on stability

The environments are updated frequently (but irregularly).  This comes with a
catch:  Updating an environment potentially introduces problems that are not
immediately visible when testing the updated installation.  To at least
partially make up for this, the state of the environments _before_ an update is
copied to `<willis_home_dir>/TM/software/miniconda3_previous`.  So if you
suddenly run into problems in an environment that used to work.  Switch to
`miniconda3_previous` and check if this helps.  If you find problems, please
[file an issue here][issues].

## Using the environments on nb.geomar.de

There is an installer which allows for adding kernels using these environments
on any of the machines that are currently supported.  See
https://git.geomar.de/python/nb/wikis/how_to_use_nb_geomar_de#install-standard-kernels-recommended
for details.

## Installing the environments on an own machine

### Complete setup on Linux

There is a setup script doing a full setup:
[setup_anaconda.sh](https://git.geomar.de/python/conda_environments/tree/master/setup_anaconda.sh)

Run it without arguments to get a help message.

To install all environments defined in
[envs/](https://git.geomar.de/python/conda_environments/tree/master/envs/)
to a path `<target_dir>`, run:
```bash
git clone git@git.geomar.de:python/conda_environments.git
cd conda_environments
./setup_anaconda.sh <target dir> envs/*
```

> **Note** that you might not want to install all environments.  If you're
> unsure, use only `envs/py3_std.yml` (and maybe `py2_std.yml`).

Then, follow the steps above to activate the respective enviroment.

### Complete setup on MacOSX

There is a setup script doing a full setup:
[setup_anaconda_MacOSX.sh](https://git.geomar.de/python/conda_environments/tree/master/setup_anaconda_MacOSX.sh)

Run it without arguments to get a help message.

To install all environments defined in
[envs/](https://git.geomar.de/python/conda_environments/tree/master/envs/)
to a path `<target_dir>`, run:
```bash
git clone git@git.geomar.de:python/conda_environments.git
cd conda_environments
./setup_anaconda_MacOSX.sh <target dir> envs/*
```

> **Note** that you might not want to install all environments.  If you're
> unsure, use only `envs/py3_std.yml` (and maybe `py2_std.yml`).

Then, follow the steps above to activate the respective enviroment.

### Adding an environment to an existing setup

If you have an own instance of `miniconda`, you can first activate its `root`
environment, with something like
```bash
source <path-to-miniconda-bin>/activate root
```
and then use
```bash
conda env create -f envs/<envname>.yml
```

### Updating an environment

There is an update script:
[update_anaconda.sh](https://git.geomar.de/python/conda_environments/tree/master/update_anaconda.sh)

In principle, you can run:
```bash
conda env update -f envs/<envname>.yml
```
There may, however, be envs using `pip` to download source code directly.
These may fail to really update.

Hence, it is usually advisable to first
```bash
conda env remove -n <envname>
```
and then
```bash
conda env create -f envs/<envname>.yml
```


## Advanced topics

### Install from an offline mirror

In `_envs_*`, there are env files matching those in the main directory which
point to local mirrors instead of the channels.  Use these if you're behind a
firewall.  (But note that on the machines where local mirrors are available,
there should be a working installation providing these envs anyway.)
